csep.core.regions.Polygon
=========================

.. currentmodule:: csep.core.regions

.. autoclass:: Polygon

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Polygon.__init__
      ~Polygon.centroid
      ~Polygon.contains
      ~Polygon.from_great_circle_radius
      ~Polygon.get_xcoords
      ~Polygon.get_ycoords
   
   

   
   
   